@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.20 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -113,14 +113,16 @@ class SyL_ConfigActions extends SyL_Config
      */
     function parseXml()
     {
-        if (SYL_PROJECT_CACHE_DIR) {
+        if (SYL_CACHE) {
             // åѤ
-            $cache =& $this->getCacheObject(SYL_PROJECT_CACHE_DIR . 'actions', $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName());
+            $key = $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName();
+            $cache =& $this->getCache($key);
             if ($cache) {
+                // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
                 // åѥ᡼¸
                 $this->config[$this->action_cache_key] = $this->action_cache_value;
-                $cache->write($this->getCache());
+                $cache->write($this->config);
             } else {
                 // åѥ᡼
                 $this->action_cache_value = $this->config[$this->action_cache_key];
