@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.3 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.3 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -151,13 +151,27 @@ class SyL_ContextWeb extends SyL_ContextJs
     }
 
     /**
-     * RSS֥Ȥ򥻥å
+     * XML֥ȡSyL_XmlWriterˤ򥻥å
+     *
+     * @access public
+     * @param object XML֥
+     * @param string ƥĥ
+     */
+    function setDisplayXml($rss_object, $type='text/xml')
+    {
+        $this->setViewType('xml');
+        $this->setParameter('_xml_type',    $type);
+        $this->setParameter('_xml_object',  $rss_object);
+    }
+
+    /**
+     * RSS֥ȡSyL_XmlRssWriterˤ򥻥å
      *
      * @access public
      * @param object RSS֥
      * @param string ƥĥ
      */
-    function setDisplayRssObject($rss_object, $type='text/xml')
+    function setDisplayRss($rss_object, $type='text/xml')
     {
         $this->setViewType('rss');
         $this->setParameter('_rss_type',    $type);
