@@ -27,16 +27,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.10 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.11 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ѥץѥƥ饹
- */
-require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
-
 /**
  * åץɥեݻ饹
  *
@@ -47,7 +42,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.10 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.11 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestFile extends SyL_UtilProperty
