@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.4 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.5 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.4 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.5 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterXmlrpc extends SyL_Router
@@ -81,7 +81,7 @@ class SyL_RouterXmlrpc extends SyL_Router
 
         // 饹ե
         $classname = implode('_', array_map('ucfirst', $pathinfo));
-        if ($classname != '') {
+        if ($classname) {
             $this->action_class = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
         } else {
             $this->action_class = ucfirst(basename($this->action_file,$this->exe_ext));
