@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.23 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.23 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -178,8 +178,6 @@ class SyL_Controller
         define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_WARN);
         // ץȥǥ쥯ȥ
         define('SYL_PROJECT_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
-        // å
-        define('SYL_PROJECT_CACHE_DIR', (isset($config['cache_dir']) && $config['cache_dir']) ? SYL_PROJECT_DIR . $config['cache_dir'] : false);
         // ץեǥ쥯ȥ
         define('SYL_PROJECT_CONFIG_DIR',  SYL_PROJECT_DIR . '/config');
         // ץȥ饤֥ǥ쥯ȥ
@@ -187,6 +185,23 @@ class SyL_Controller
         // ץꥱǥ쥯ȥ
         define('SYL_APP_DIR', SYL_PROJECT_DIR . '/app/' . $config['app_name']);
 
+        // å
+        define('SYL_CACHE', (isset($config['cache']) && $config['cache']) ? $config['cache'] : false);
+        switch (SYL_CACHE) {
+        case 'file':
+            if (!isset($config['cache_dir']) || !$config['cache_dir']) {
+                trigger_error("[SyL error] Undefined cache file directory in initialise parameter `cache_dir'", E_USER_ERROR);
+            }
+            define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . $config['cache_dir']);
+            break;
+        case 'memcache':
+            if (!isset($config['cache_host']) || !$config['cache_host']) {
+                trigger_error("[SyL error] Undefined memcache host in initialise parameter `cache_host'", E_USER_ERROR);
+            }
+            define('SYL_CACHE_MEMCACHE_HOST', $config['cache_host']);
+            break;
+        }
+
         // ɤ߹
         call_user_func(array(&$this, 'readDefines'));
 
@@ -253,7 +268,7 @@ class SyL_Controller
         $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
 
         // åѤʤ
-        $config =& SyL_Config::getObject('defines', $config_files, $this);
+        $config =& SyL_Config::factory('defines', $config_files, $this);
         $config->parseXml();
     }
 
