@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.1 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,14 +41,22 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * ե졼ǡݻ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.1 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
 {
+    /**
+     * ϥǡ
+     *
+     * @access protected
+     * @var array
+     */
+    var $input_parameters = array();
+
     /**
      * ǡݻ饹Υ󥹥󥹼
      *
@@ -121,6 +129,112 @@ class SyL_Data extends SyL_UtilProperty
         }
     }
 
+    /**
+     * ץѥƥ
+     * 
+     * @access public
+     * @param string ץѥƥ̾
+     * @return string ץѥƥ
+     */
+    function get($name)
+    {
+        $value = parent::get($name);
+        if (($value === null) && isset($this->input_parameters[$name])) {
+            $value = $this->input_parameters[$name];
+        }
+        return $value;
+    }
+
+    /**
+     * ץѥƥʻȡ
+     * 
+     * @access public
+     * @param string ץѥƥ̾
+     * @return string ץѥƥ
+     */
+    function &getRef($name)
+    {
+        $value =& parent::getRef($name);
+        if (($value === null) && isset($this->input_parameters[$name])) {
+            $value =& $this->input_parameters[$name];
+        }
+        return $value;
+    }
+
+    /**
+     * ץѥƥ
+     * 
+     * @access public
+     * @return array ץѥƥ
+     */
+    function gets()
+    {
+        return parent::gets() + $this->input_parameters;
+    }
+
+    /**
+     * ץѥƥʻȡ
+     * 
+     * @access public
+     * @return array ץѥƥ
+     */
+    function &getsRef()
+    {
+        $values =& parent::getsRef();
+        foreach (array_keys($this->input_parameters) as $name) {
+            if (!isset($values[$name])) {
+                $values[$name] =& $this->input_parameters[$name];
+            }
+        }
+        return $values;
+    }
+
+    /**
+     * ϥѥ᡼򥻥å
+     * 
+     * @access public
+     * @param array ϥѥ᡼
+     */
+    function setInputParameters($values)
+    {
+        $this->input_parameters = $values;
+    }
+
+    /**
+     * ѥ᡼ϡʻȡ
+     * 
+     * @access public
+     * @return array ϥѥ᡼
+     */
+    function &getOutputParameters()
+    {
+        return parent::getsRef();
+    }
+
+    /**
+     * ϥѥ᡼ϥѥ᡼ƩŪϤ
+     * 
+     * @access public
+     */
+    function throwParameters()
+    {
+        $this->sets($this->input_parameters);
+    }
+
+    /**
+     * ѥ᡼˻ؿŬѤ
+     * 
+     * @access private
+     * @param array ѥ᡼
+     * @param string ؿ̾
+     */
+    function apply($func)
+    {
+        $func_parameters = func_get_args();
+        $func = array_shift($func_parameters);
+        parent::apply($func, $func_parameters);
+        parent::applyRecursive($func, $this->input_parameters, $func_parameters);
+    }
 
     /**
      * ץ饤١ȥץѥƥ̾å
