@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.14 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.15 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.14 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.15 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -116,7 +116,7 @@ class SyL_Request
      function createParameter()
      {
          include_once SYL_INCLUDE_DIR . "/framework/Request/SyL_RequestParameter.php";
-         $this->parameter =& new $classname();
+         $this->parameter =& new SyL_RequestParameter();
      }
 
     /**
@@ -320,6 +320,17 @@ class SyL_Request
         return $this->files;
     }
 
+    /**
+     * ϐl擾
+     *
+     * @access public
+     * @param string ϐ
+     * @return string ϐl
+     */
+    function getServerVer($name)
+    {
+        return isset($_SERVER[$name]) ? $_SERVER[$name] : null;
+    }
 }
 
 ?>
