@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.12 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.12 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -58,7 +58,7 @@ class SyL_Response
      * @access public
      * @return object HTTP쥹ݥ󥹥֥
      */
-    function &getInstance()
+    function &singleton()
     {
         static $singleton;
         if (!is_object($singleton)) {
@@ -131,7 +131,7 @@ class SyL_Response
             SyL_Loggers::info("[Response] Redirect(301) -> {$url}");
         }
         SyL_Response::setHeader('Location', $url);
-        $obj =& SyL_Response::getInstance();
+        $obj =& SyL_Response::singleton();
         $obj->sendHeader();
 
         exit;
@@ -168,8 +168,8 @@ class SyL_Response
      */
     function setHeader($name, $value='')
     {
-        $obj =& SyL_Response::getInstance();
-        $obj->headers[$name] = $value;
+        $response =& SyL_Response::singleton();
+        $response->headers[$name] = $value;
     }
 
     /**
@@ -197,8 +197,8 @@ class SyL_Response
     {
         $name = strtolower($name);
 
-        $obj =& SyL_Response::getInstance();
-        foreach ($obj->getCustomHeaders() as $tmp_name => $tmp_value) {
+        $response =& SyL_Response::singleton();
+        foreach ($response->getCustomHeaders() as $tmp_name => $tmp_value) {
             if ($name == strtolower($tmp_name)) {
                 return $tmp_value;
             }
@@ -241,11 +241,11 @@ class SyL_Response
      */
     function sendHeader()
     {
-        foreach ($this->getCustomHeaders() as $tmp_name => $tmp_value) {
-            if ($tmp_value) {
-                header("$tmp_name: $tmp_value");
+        foreach ($this->getCustomHeaders() as $name => $value) {
+            if ($value) {
+                header("$name: $value");
             } else {
-                header("$tmp_name");
+                header("$name");
             }
         }
     }
@@ -284,6 +284,11 @@ class SyL_Response
      */
     function display(&$view)
     {
+        $data           = '';
+        $content_type   = false;
+        $content_length = false;
+        $gzip_compress  = false;
+
         if (is_object($view)) {
             if (is_a($view, 'SyL_ViewNull')) {
                 return;
@@ -292,23 +297,100 @@ class SyL_Response
             $content_type   =  $view->getContentType();
             $content_length =  $view->isContentLength();
             $gzip_compress  =  $view->isGzipCompress();
-
-            // ƥĥפ򥻥å
-            if ($content_type) {
-                SyL_Response::setHeader('Content-Type', $content_type);
-            }
-
-            // gzip̤ѲǽʤѤ
-            if (!$gzip_compress || !$this->convertGzip($data)) {
-                // gzip̤ʤ硢ƥ̤򥻥å
-                if ($content_length) {
-                    SyL_Response::setHeader('Content-Length', strlen($data));
-                }
-            }
         } else {
             $data =& $view;
         }
 
+        // Last-Modified & EtagåλȽ
+        if (SYL_CACHE && SYL_RESPONSE_LAST_MODIFIED_CACHE && (
+             (isset($_SESSION)  && (SYL_SESSION_CACHE  != 'nocache')) ||
+             (!isset($_SESSION) && (SYL_RESPONSE_CACHE != 'nocache'))
+           )) {
+            // ǿMD5
+            $data_new_md5 = md5($data);
+
+            // å奯饹
+            include_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
+            // å奪֥ȼ
+            $cache =& SyL_Cache::factory(SYL_CACHE);
+            $cache->setPrefix('response.');
+            $cache->setKey($_SERVER['REQUEST_URI']);
+
+            // HTTP_IF_NONE_MATCH
+            $if_none_match = isset($_SERVER['HTTP_IF_NONE_MATCH']) ? $_SERVER['HTTP_IF_NONE_MATCH'] : '';
+            // Last-Modified
+            $if_modified_since = isset($_SERVER['HTTP_IF_MODIFIED_SINCE']) ? $_SERVER['HTTP_IF_MODIFIED_SINCE'] : '';
+
+            if ($if_none_match) {
+                $if_none_match = trim(strtr($if_none_match, array('\\"' => '', '"' => '')));
+                // ǿMD5ȡʥ֥饦˥åMD5
+                if ($data_new_md5 == $if_none_match) {
+                    // ѹʤ
+                    SyL_Loggers::info("[Response] Not Modified(304) Etag: {$data_new_md5}");
+                    SyL_Response::setStatusHeader('304');
+                    $this->sendHeader();
+                    exit;
+                } else {
+                    // åǿMD5ؤ
+                    $cache->write($data_new_md5);
+                }
+            } else if ($if_modified_since) {
+                $cache->setMaxModifyTime(strtotime($if_modified_since));
+                // ǿMD5ȥåMD5
+                if ($data_new_md5 == $cache->read()) {
+                    // ѹʤ
+                    SyL_Loggers::info("[Response] Not Modified(304) Etag: {$data_new_md5}");
+                    SyL_Response::setStatusHeader('304');
+                    $this->sendHeader();
+                    exit;
+                } else {
+                    // åǿMD5ؤ
+                    $cache->write($data_new_md5);
+                }
+            } else {
+                if ($cache->read() === false) {
+                    // åʤ => å
+                    $cache->write($data_new_md5);
+                }
+            }
+            // Last-Modifiedå
+            SyL_Response::setHeader('Last-Modified', gmdate('D, d M Y H:i:s T', $cache->getModifyTime()));
+            // Etagå
+            SyL_Response::setHeader('Etag', '"' . $data_new_md5 . '"');
+        }
+
+        // ƥĥפ򥻥å
+        if ($content_type) {
+            SyL_Response::setHeader('Content-Type', $content_type);
+        }
+        // gzip̤ѲǽʤѤ
+        if ($gzip_compress) {
+            $this->convertGzip($data);
+        }
+        // ƥ̤򥻥å
+        if ($content_length) {
+            SyL_Response::setHeader('Content-Length', strlen($data));
+        }
+
+        // åإå򥻥å
+        if (!isset($_SESSION)) {
+            switch (SYL_RESPONSE_CACHE) {
+            case 'nocache':
+                SyL_Response::setHeader('Cache-Control', 'no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
+                SyL_Response::setHeader('Expires', 'Thu, 19 Nov 1981 08:52:00 GMT');
+                SyL_Response::setHeader('Pragma', 'no-cache');
+                break;
+            case 'private':
+                SyL_Response::setHeader('Expires', 'Thu, 19 Nov 1981 08:52:00 GMT');
+            case 'private_no_expire':
+                SyL_Response::setHeader('Cache-Control', 'private, max-age=10800, pre-check=10800');
+                break;
+            case 'public':
+                SyL_Response::setHeader('Cache-Control', 'public, max-age=10800');
+                break;
+            }
+        }
+
         // إå
         $this->sendHeader();
         // ɽǡ
