@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.4 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.4 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayout extends SyL_View
@@ -72,7 +72,7 @@ class SyL_ViewLayout extends SyL_View
         // 쥤
         $config_files[] = SYL_APP_DIR . "/{$this->layout_file_name}";
 
-        $config =& SyL_Config::getObject('layouts', $config_files, $context->controller);
+        $config =& SyL_Config::factory('layouts', $config_files, $context->controller);
         $config->parseXml();
         $this->config = $config->getConfig();
 
