@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.16 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.16 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -166,8 +166,15 @@ class SyL_DB
      * @access public
      * @param string ³ʸ
      */
-    function &getConnection($dsn, $server_encode='')
+    function &getConnection($dsn='', $server_encode='')
     {
+        if (!$dsn) {
+            if (defined('SYL_DB_DSN')) {
+                $dsn = SYL_DB_DSN;
+            } else {
+                trigger_error("[SyL error] DSN(connection string) not found", E_USER_ERROR);
+            }
+        }
         static $singleton = array();
         if (!isset($singleton[$dsn]) || !is_object($singleton[$dsn])) {
             $tmp  = explode(':', $dsn, 2);
@@ -185,11 +192,11 @@ class SyL_DB
                 $dbtype = $type;
             }
 
-            $class_name = 'SyL_DB' . $type;
+            $classname = 'SyL_DB' . $type;
 
             // ¥󥹥󥹺
-            include_once dirname(__FILE__) . "/DB/{$class_name}.php";
-            $singleton[$dsn] = new $class_name($dbtype);
+            include_once dirname(__FILE__) . "/DB/{$classname}.php";
+            $singleton[$dsn] = new $classname($dbtype);
             if ($server_encode) $singleton[$dsn]->server_encode = $server_encode;
             if ($client_encode) $singleton[$dsn]->client_encode = $client_encode;
             if (!$singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent)) {
