@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.11 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.12 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ set_magic_quotes_runtime(0);
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.11 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.12 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_File
@@ -70,6 +70,13 @@ class SyL_File
      * @var string
      */
     var $mode;
+    /**
+     * ѡߥå
+     * 
+     * @access protected
+     * @var int
+     */
+    var $permission = 0000;
     /**
      * ԥ
      * 
@@ -169,6 +176,10 @@ class SyL_File
         if (!is_resource($this->fp)) {
             trigger_error("[SyL error] Function fopen failed. file not found or permission denied? ({$this->resource_name})", E_USER_ERROR);
         }
+        if ($this->permission) {
+            @chmod($this->resource_name, $this->permission);
+            $this->permission = 0000;
+        }
         //register_shutdown_function(array(&$this, 'close'));
     }
 
@@ -183,6 +194,10 @@ class SyL_File
             fclose($this->fp);
             $this->fp = null;
         }
+        if ($this->permission) {
+            @chmod($this->resource_name, $this->permission);
+            $this->permission = 0000;
+        }
         if ($this->current_umask !== null) {
             umask($this->current_umask);
         }
@@ -253,6 +268,17 @@ class SyL_File
         }
     }
 
+    /**
+     * ѡߥå򥻥åȤ
+     *
+     * @access public
+     * @param int ѡߥå(8ʿ : 0755)
+     */
+    function setPermission($permission)
+    {
+        $this->permission = $permission;
+    }
+
     /**
      * ѤԤ򥻥åȤ
      *
