@@ -1,4 +1,37 @@
 <?php
+/**
+ * -----------------------------------------------------------------------------
+ *
+ * SyL - Web Application Framework for PHP
+ *
+ * PHP version 4 (>= 4.3.x) or 5
+ *
+ * Copyright (C) 2006-2007 k.watanabe
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * -----------------------------------------------------------------------------
+ * @package   SyL
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
+ * @copyright 2006-2007 k.watanabe
+ * @license   http://www.opensource.org/licenses/lgpl-license.php
+ * @version   CVS: $Id: index.php,v 1.3 2007/06/05 13:08:24 seasonstream Exp $
+ * @link      http://www.syl.jp/
+ * -----------------------------------------------------------------------------
+ */
+
 /**
  * ץȺ饹
  *
@@ -6,13 +39,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: index.php,v 1.2 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: index.php,v 1.3 2007/06/05 13:08:24 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index
 {
-    var $version = SYL_VERSION;
-
     var $c_action; // 󥸥
     var $c_application; // 󥸥
     var $c_controller; // 󥸥
@@ -29,11 +60,11 @@ class Index
     }
 
     /**
-     * ɽ
+     * ᥤ
      *
      * @access public
-     * @param object ܾ󥪥֥
-     * @param object ݡͥȥ᥽åɥ֥
+     * @param object ǡ֥
+     * @param object ƥȥ֥
      */
     function execute(&$data, &$context)
     {
@@ -83,12 +114,12 @@ class Index
         default:
             // С󥳥ޥ
             if ($data->is('h') || $data->is('-help')) {
-                $this->displayHelp($data->get(0), $cmd);
+                $this->displayHelp($cmd, $data->get(0));
             // إץޥ
             } else if ($data->is('v') || $data->is('-version')) {
-                $this->displayVersion($data->get(0), $cmd);
+                $this->displayVersion($cmd, $data->get(0));
             } else {
-                $this->displayDefault($data->get(0), $cmd);
+                $this->displayDefault($cmd, $data->get(0));
             }
         }
     }
@@ -96,10 +127,11 @@ class Index
     /**
      * إפɽ
      *
-     * @access public
-     * @param object ܾ󥪥֥
+     * @access private
+     * @param object ޥɥ֥
+     * @param string ¹ԥե̾
      */
-    function displayHelp($file, &$cmd)
+    function displayHelp(&$cmd, $file)
     {
         $help = <<<EOF
 Usage:
@@ -125,17 +157,19 @@ EOF;
     /**
      * Сɽ
      *
-     * @access public
-     * @param object ܾ󥪥֥
+     * @access private
+     * @param object ޥɥ֥
+     * @param string ¹ԥե̾
      */
-    function displayVersion($file, &$cmd)
+    function displayVersion(&$cmd, $file)
     {
+        $syl_version = SYL_VERSION;
         $php_version = PHP_VERSION;
         $php_sapi    = PHP_SAPI;
         $php_os      = PHP_OS;
        // $php_version = PHP_SAPI;
         $version = <<<EOF
-{$file} - SyL {$this->version} (on PHP {$php_version} {$php_sapi} - {$php_os})
+{$file} - SyL {$syl_version} (PHP {$php_version} {$php_sapi} - {$php_os})
 Copyright (c) 2006-2007 k.watanabe
 EOF;
         $cmd->stdout($version);
@@ -144,10 +178,11 @@ EOF;
     /**
      * ǥեɽ
      *
-     * @access public
-     * @param object ܾ󥪥֥
+     * @access private
+     * @param object ޥɥ֥
+     * @param string ¹ԥե̾
      */
-    function displayDefault($file, &$cmd)
+    function displayDefault(&$cmd, $file)
     {
         $default = <<<EOF
 {$file}: too few arguments
